Setting Log Levels — sdx-common 0.7.1 documentation

# Setting Log Levels

Use this module to set the logging level of imported modules, where they implement standard python logging setups.

`sdx.common.log_levels.` `set_level`(logger=None, log_level=None)

  Set logging levels using logger names.

  Parameters: | logger (String) – Name of the logger log_level (String) – A string or integer corresponding to a Python logging level
  Return type: | None